@@ -3,6 +3,7 @@ import os
 import binascii
 import codecs
 import grpc
+# import aiogrpc
 import json
 from google.protobuf.json_format import MessageToJson
 from google.protobuf.json_format import MessageToDict
@@ -17,6 +18,7 @@ import python_lnd_grpc.protos.walletunlocker_pb2_grpc as walletunlockerstub
 TLS_FILE_PATH = '~/.lnd/'
 ADMIN_MACAROON_PATH = '~/.lnd/data/chain/bitcoin/'
 
+os.environ['GRPC_SSL_CIPHER_SUITES'] = 'HIGH+ECDSA'
 
 class Connector(object):
     def __init__(
@@ -31,33 +33,39 @@ class Connector(object):
         custom_tls_path_full: str = None,
         custom_macaroon_path_full: str = None,
         output: str = None,
-        macaroon_bytes: bytes = None):
+        is_wallet_unlocker: bool = False,
+        macaroon_bytes: bytes = None,
+        tls_file_bytes: bytes = None):
 
         # TODO move to separate method
         if custom_tls_path_full is not None:
             self.tls_file = os.path.expanduser(custom_tls_path_full)
         else:
             self.tls_file = os.path.expanduser(tls_file_path + tls_file_name)
-        # print(self.tls_file)
 
-        # TODO move to separate method
-        if custom_macaroon_path_full is not None:
-            self.full_macaroon_path = os.path.expanduser(custom_macaroon_path_full)
+         # TODO move to separate method
+        if tls_file_bytes is not None:
+            self.cert = tls_file_bytes
         else:
-            self.full_macaroon_path = os.path.expanduser((macaroon_path + '{}/' + macaroon_filename).format(network))
-        
-        # print(self.full_macaroon_path)
-        with open(self.tls_file, 'rb') as f:
-            self.cert = f.read()
+            with open(self.tls_file, 'rb') as f:
+                self.cert = f.read()
 
-        if macaroon_bytes is not None:
-            self.macaroon = codecs.encode(macaroon_bytes, 'hex')
-        else:    
-            with open(self.full_macaroon_path, 'rb') as f:
-                self.macaroon_bytes = f.read()
-                self.macaroon = codecs.encode(self.macaroon_bytes, 'hex')
-
-        self.headers = {'Grpc-Metadata-macaroon': self.macaroon}
+        if not is_wallet_unlocker:
+            # TODO move to separate method
+            if custom_macaroon_path_full is not None:
+                self.full_macaroon_path = os.path.expanduser(custom_macaroon_path_full)
+            else:
+                self.full_macaroon_path = os.path.expanduser((macaroon_path + '{}/' + macaroon_filename).format(network))
+            
+            # TODO move to separate method
+            if macaroon_bytes is not None:
+                self.macaroon = codecs.encode(macaroon_bytes, 'hex')
+            else:    
+                with open(self.full_macaroon_path, 'rb') as f:
+                    self.macaroon_bytes = f.read()
+                    self.macaroon = codecs.encode(self.macaroon_bytes, 'hex')
+                    self.headers = {'Grpc-Metadata-macaroon': self.macaroon}
+                    
         self.host = grpc_host
         self.port = grpc_port
         self.output = output
@@ -216,6 +224,20 @@ class LNDMethods(Connector):
         response = self._ln_stub.EstimateFee(request)
         return self.out(response)
 
+    # https://api.lightning.community/#exportallchannelbackups
+    def exportallchannelbackups(self):
+        request = lnrpc.ChanBackupExportRequest()
+        response = self._ln_stub.ExportAllChannelBackups(request)
+        return self.out(response)
+
+    # https://api.lightning.community/#exportchannelbackup
+    def exportchannelbackup(self, chan_point):
+        request = lnrpc.ExportChannelBackupRequest(
+            chan_point=chan_point,
+        )
+        response = self._ln_stub.ExportChannelBackup(request)
+        return self.out(response)
+
     # https://api.lightning.community/#feereport
     def feereport(self):
         response = self._ln_stub.FeeReport(lnrpc.FeeReportRequest())
@@ -481,7 +503,8 @@ class LNDMethods(Connector):
         response = self._ln_stub.SendPaymentSync(request)
         return self.out(response)
 
-    def sendtoroute(self, payment_hash: bytes, payment_hash_string: str, route):
+    # https://api.lightning.community/#sendtoroutesync
+    def sendtoroutesync(self, payment_hash: bytes, payment_hash_string: str, route):
         request = lnrpc.SendToRouteRequest(
             payment_hash=payment_hash,
             payment_hash_string=payment_hash_string,
@@ -490,12 +513,11 @@ class LNDMethods(Connector):
         response = self._ln_stub.SendToRouteSync(request)
         return self.out(response)
 
+    # https://api.lightning.community/#subscribechannelbackups
     def subscribechannelbackups(self):
         response = self._ln_stub.SubscribeChannelBackups(lnrpc.ChannelBackupSubscription())
         return self.out(response)
 
-    
-
     # https://api.lightning.community/#walletbalance
     def walletbalance(self):
         response = self._ln_stub.WalletBalance(lnrpc.WalletBalanceRequest()) 
@@ -511,4 +533,4 @@ class LNDMethods(Connector):
         )
         response = self.ln_stub.FeeReport(lnrpc.FeeReportRequest())
         return response
-    '''
\ No newline at end of file
+    '''
